ProgressBar

Struct ProgressBar 

pub struct ProgressBar { /* private fields */ }
structure representing a progressbar

Implementations

Source

impl ProgressBar

pub fn new(text: &str, empty: char, full: char) -> ProgressBar

create a new progress bar

Arguments

*text: the text to use for the progress bar *empty: the character to use for empty progress bar fields *full: the character to use for full progress bar fields

Returns

Returns a new progress bar

pub fn incr(&mut self)

increase the current progress

pub fn set_progress(&mut self, amount: f32)

set the current progress

pub fn render(&self) -> String

render the current progress bar